==> haskell-tasty-hslua-1.0.2-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-hslua.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-hslua
version:              1.0.2
visibility:           public
id:                   tasty-hslua-1.0.2-8T5GwdboLomHzGh4lKIML
key:                  tasty-hslua-1.0.2-8T5GwdboLomHzGh4lKIML
license:              MIT
copyright:            © 2017-2022 Albert Krewinkel
maintainer:           albert+hslua@zeitkraut.de
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Tasty helpers to test HsLua.
description:
    Various tasty helpers and utilities to test HsLua
    oparations. Built on top of tasty-hunit.

category:             Foreign
abi:                  eed4d5ae466aa802a89984fc08539c2d
exposed:              True
exposed-modules:      Test.Tasty.HsLua
import-dirs:          /usr/lib/ghc-9.0.2/site-local/tasty-hslua-1.0.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/tasty-hslua-1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-hslua
hs-libraries:         HStasty-hslua-1.0.2-8T5GwdboLomHzGh4lKIML
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    hslua-core-2.1.0-3FRz0n2z0ob6x88v7baw1R
    tasty-1.4.2.1-HVuDzWMIBqVBSvpu0oeERb
    tasty-hunit-0.10.0.3-CCJJv9B2n42Cd99Jqwvtkt

haddock-interfaces:   /usr/share/doc/haskell-tasty-hslua/html/tasty-hslua.haddock
haddock-html:         /usr/share/doc/haskell-tasty-hslua/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-hslua-1.0.2-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-hslua.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-hslua
version:              1.0.2
visibility:           public
id:                   tasty-hslua-1.0.2-2Q8OMNh0H4A8NPbLkH7etZ
key:                  tasty-hslua-1.0.2-2Q8OMNh0H4A8NPbLkH7etZ
license:              MIT
copyright:            © 2017-2022 Albert Krewinkel
maintainer:           albert+hslua@zeitkraut.de
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Tasty helpers to test HsLua.
description:
    Various tasty helpers and utilities to test HsLua
    oparations. Built on top of tasty-hunit.

category:             Foreign
abi:                  902d0140d915f84e8e520b2c3342fc9d
exposed:              True
exposed-modules:      Test.Tasty.HsLua
import-dirs:          /usr/lib/ghc-9.0.2/site-local/tasty-hslua-1.0.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/tasty-hslua-1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-hslua
hs-libraries:         HStasty-hslua-1.0.2-2Q8OMNh0H4A8NPbLkH7etZ
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    hslua-core-2.1.0-6jFHRva9WSvHLqA5p5zU0m
    tasty-1.4.2.1-688Gugn3BU24DLKxXCsjqf
    tasty-hunit-0.10.0.3-GDO83eg5TYXBJWNtDuBzIX

haddock-interfaces:   /usr/share/doc/haskell-tasty-hslua/html/tasty-hslua.haddock
haddock-html:         /usr/share/doc/haskell-tasty-hslua/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
